@@ -89,7 +89,7 @@ class BasePredictor:
         batch_size = len(data) // num_batches
         if batch_size < 1:
             num_batches = batch_size = 1
-        #prediction_all = np.zeros(shape=out_shape)
+        # prediction_all = np.zeros(shape=out_shape)
         prediction_all = torch.zeros(out_shape)
         for i in range(num_batches):
             if self.verbose:
@@ -107,11 +107,15 @@ class BasePredictor:
 
     def predict(self,
                 data: torch.Tensor,
+                out_shape: Tuple[int] = None,
                 num_batches: int = 1) -> torch.Tensor:
         """
         Make a prediction on the new data with a trained model
         """
-        out_shape = data.shape
+        if out_shape is None:
+            out_shape = data.shape
+        else:
+            out_shape = (data.shape[0], *out_shape)
         data = self.preprocess(data)
         prediction = self.batch_predict(data, out_shape, num_batches)
         return prediction
@@ -238,7 +242,7 @@ class SegPredictor(BasePredictor):
                 3D image stack or a single 2D image (all greyscale)
             return_image:
                 Returns images used as input into NN
-            **num_batches: number of batches
+            **num_batches (int): number of batches
             **norm (bool): Normalize data to (0, 1) during pre-processing
         """
         image_data = self.preprocess(
@@ -259,20 +263,27 @@ class SegPredictor(BasePredictor):
 
     def run(self,
             image_data: np.ndarray,
+            compute_coords=True,
             **kwargs: int) -> Tuple[np.ndarray, Dict[int, np.ndarray]]:
         """
         Make prediction with a trained model and calculate coordinates
 
         Args:
-            image_data (2D or 3D numpy array):
+            image_data:
                 Image stack or a single image (all greyscale)
-            **num_batches:
+            compute_coords:
+                Computes centers of the mass of individual blobs
+                in the segmented images (Default: True)
+            **num_batches (int):
                 number of batches for batch-by-batch prediction
                 which ensures that one doesn't run out of memory
                 (Default: 10)
             **norm (bool): Normalize data to (0, 1) during pre-processing
         """
         start_time = time.time()
+        if not compute_coords:
+            decoded_imgs = self.predict(image_data, **kwargs)
+            return decoded_imgs
         images, decoded_imgs = self.predict(
             image_data, return_image=True, **kwargs)
         loc = Locator(self.thresh, refine=self.refine, d=self.d)
@@ -300,7 +311,7 @@ class ImSpecPredictor(BasePredictor):
             Use GPU accelration for prediction
         verbose:
             Verbosity
-    
+
     Example:
 
         >>> # Predict spectra from images with pretrained im2spec model
@@ -348,7 +359,7 @@ class ImSpecPredictor(BasePredictor):
         Predict spectra from images or vice versa
 
         Args:
-            signal (numpy array): Input image/spectrum or batch of images/spectra
+            signal: Input image/spectrum or batch of images/spectra
             **num_batches (int): number of batches (Default: 10)
             **norm (bool): Normalize data to (0, 1) during pre-processing
         """
@@ -365,7 +376,7 @@ class ImSpecPredictor(BasePredictor):
         Make prediction with a trained model
 
         Args:
-            signal (numpy array): Input image/spectrum or batch of images/spectra
+            signal: Input image/spectrum or batch of images/spectra
             **num_batches (int): number of batches (Default: 10)
             **norm (bool): Normalize data to (0, 1) during pre-processing
         """
@@ -388,13 +399,13 @@ class Locator:
     Transforms pixel data from NN output into coordinate data
 
     Args:
-        decoded_imgs (4D numpy array):
+        decoded_imgs:
             Output of a neural network
-        threshold (float):
+        threshold:
             Value at which the neural network output is thresholded
-        dist_edge (int):
+        dist_edge:
             Distance within image boundaries not to consider
-        dim_order (str):
+        dim_order:
             'channel_last' or 'channel_first' (Default: 'channel last')
 
     Example:
